<?php
// $Id: ticket.admin.unit.inc,v 1.1.4.3 2010/10/05 12:16:26 york Exp $

/**
 * ticket_admin_unit_list_form: Ticket unit admisztracios listaja
 * @return array - $form: unit list form
 */
function ticket_admin_unit_list_form() {
  $result = db_query("SELECT u_id, unit_name, weight, active FROM {ticket_unit} ORDER BY active DESC, weight ASC, unit_name ASC");
  while ($row = db_fetch_array($result)) {
    /** unit adminisztrator szamara lista keszites */
    $form[$row['u_id']]['info'] = array('#value' => $row['unit_name']);
    $form[$row['u_id']]['weight'] = array(
      '#type' => 'weight',
      '#default_value' => $row['weight'],
      '#attributes' => array('class' => 'unit-weight unit-weight-'. $row['u_id']),
    );
    if ( ticket_access('ticket administer', $row['u_id'], 0) ) {
      $form[$row['u_id']]['configure'] = array('#value' => l(t('edit unit'), 'admin/ticket/unit/edit/'. $row['u_id']) );
      if ($row['active']) {
        $form[$row['u_id']]['active'] = array('#value' => l(t('disable'), 'admin/ticket/unit/active/'. $row['u_id'] .'/0') );
      }
      else {
        $form[$row['u_id']]['active'] = array('#value' => l(t('enable'), 'admin/ticket/unit/active/'. $row['u_id'] .'/1') );
      }
    }
    else {
      $form[$row['u_id']]['configure'] = array('#value' => t('edit unit'));
    }
  }

  $form['#action'] = url('admin/ticket/unit/list/');
  $form['#tree'] = TRUE;
  $form['submit'] = array(
    "#type" => "submit",
    "#value" => t('Save configuration'),
  );
  return $form;
}

/**
 * ticket_admin_unit_list_form_submit: unit weight beallitasa
 */
function ticket_admin_unit_list_form_submit($form, &$form_state) {
  foreach ($form_state['values'] as $u_id => $weight) {
    if ( is_numeric($u_id) ) {
      $SQL = "UPDATE {ticket_unit} SET weight = %d WHERE u_id = %d";
      db_query($SQL, $weight['weight'], $u_id);
    }
  }
}

/**
 * _ticket_admin_unit_form:
 * @param $def - unit form default erteki
 * @return array - $form: unit add/edit form
 */
function _ticket_admin_unit_form($def = array()) {
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Unit name'),
    '#default_value' => isset($def['unit_name']) ? $def['unit_name'] : NULL,
    '#size' => 60,
    '#maxlength' => 255,
    '#required' => TRUE,
  );

  $form['desc'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#default_value' => isset($def['description']) ? $def['description'] : NULL,
    '#required' => FALSE,
  );

  $form['weight'] = array(
    '#type' => 'weight',
    '#title' => t('Weight'),
    "#type" => "weight",
    '#default_value' => isset($def['weight']) ? $def['weight'] : NULL,
  );

  $form['active'] = array(
    '#type' => 'select',
    '#title' => t('Active'),
    '#default_value' => isset($def['active']) ? $def['active'] : NULL,
    '#options' => array(
      '1' => t('Yes'),
      '0' => t('No'),
    ),
  );
  return $form;
}

/**
 * ticket_admin_add_unit: unit hozzaadas
 */
function ticket_admin_unit_add() {
  $form = _ticket_admin_unit_form(array('weight' => 0));
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save')
  );
  return $form;
}

/**
 * ticket_admin_add_unit_validate: add unit formrol erkezo adatok ellenorzese
 */
function ticket_admin_unit_add_validate($form, &$form_state) {
  /** azonos nevu unit nem johet letre */
  $result = db_query("SELECT count(u_id) as num FROM {ticket_unit} WHERE unit_name = '%s'", $form_state['values']['name']);
  $row = db_fetch_array($result);

  if ( $row['num'] ) {
    form_set_error('', t('You must select a name for this unit of settings.'));
  }
}

/**
 * ticket_admin_add_unit_submit: unit hozzaadas
 */
function ticket_admin_unit_add_submit($form, &$form_state) {
  /** unit hozzaadasa */
  $SQL = "INSERT INTO {ticket_unit} (unit_name, description, weight, active) VALUES ('%s', '%s', %d, %d)";
  db_query($SQL, $form_state['values']['name'], $form_state['values']['desc'], $form_state['values']['weight'], $form_state['values']['active']);
  menu_rebuild();
}

/**
 * ticket_admin_edit_unit: unit szerkesztes
 * @param $form_state - drupal $form_state variable
 * @param $u_id - unit id
 * @return array - $form: unit edit form
 */
function ticket_admin_unit_edit(&$form_state, $u_id) {
  /** breadcrumb kiegeszitese */
  $bc = drupal_get_breadcrumb();
  $bc[] = l(t('Units'), 'admin/ticket/unit/');
  drupal_set_breadcrumb($bc);

  /** unit lekerdezese, a vissza adott ertekek atadasa a formnak */
  $result = db_query("SELECT * FROM {ticket_unit} WHERE u_id = %d", $u_id);
  $def = db_fetch_array($result);

  $form = _ticket_admin_unit_form($def);
  $form['u_id'] = array(
    '#type' => 'value',
    '#value' => $u_id,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save')
  );
  return $form;
}

/**
 * ticket_admin_edit_unit_validate: edit unit formrol erkezo adatok ellenorzese
 */
function ticket_admin_unit_edit_validate($form, &$form_state) {
  /** azonos nevu unit nem johet letre */
  $result = db_query("SELECT count(u_id) as num FROM {ticket_unit} WHERE u_id <> %d AND unit_name = '%s'", $form_state['values']['u_id'], $form_state['values']['name']);
  $row = db_fetch_array($result);

  if ( $row['num'] ) {
    form_set_error('', t('You must select a name for this unit of settings.'));
  }
}

/**
 * ticket_admin_edit_unit_submit: unit modositas
 */
function ticket_admin_unit_edit_submit($form, &$form_state) {
  /** unit szerkesztese */
  $SQL = "UPDATE {ticket_unit} SET unit_name = '%s', description = '%s', weight = %d, active = %d WHERE u_id = %d";
  db_query($SQL, $form_state['values']['name'], $form_state['values']['desc'], $form_state['values']['weight'], $form_state['values']['active'], $form_state['values']['u_id']);
  menu_rebuild();
  $form_state['redirect'] = 'admin/ticket/unit';
}

/**
 * ticket_admin_unit_active: unit allapotanak modositasa: bekapcsolt / kikapcsolt
 */
function ticket_admin_unit_active($u_id, $active) {
  $SQL = "UPDATE {ticket_unit} SET active = %d WHERE u_id = %d";
  db_query($SQL, $active, $u_id);
  menu_rebuild();
  drupal_goto('admin/ticket/unit');
}




